@@ -50,7 +50,7 @@ class Yspeed:
              It supports Chrome, Firefox and Edge browsers.
     """
 
-    def best_server(self) -> dict[str, str]:
+    def best_server(self) -> dict:
         """
         Retrieves and returns detailed IP address information using the https://www.speedtest.net/ service.
         Information retrieved includes:
@@ -71,7 +71,7 @@ class Yspeed:
 
         return {"provider": provider, "Serveur": server}
 
-    def get_ip_info(self) -> dict[str, str]:
+    def get_ip_info(self) -> dict:
         """
         Retrieves information about the user's public IP address,such as city, region, country, and operator.
         This function makes a request to the ipinfo.io service to get information about the user's public IP address.
@@ -94,7 +94,7 @@ class Yspeed:
             "operator": operator,
         }
 
-    def get_speedtest(self) -> dict[str, str]:
+    def get_speedtest(self) -> dict:
         """
         Retrieves and returns the results of an Internet connection speed test using the online service Speedtest.
         The information retrieved includes:
@@ -153,6 +153,8 @@ class Yspeed:
         result = self._extracted_from_speedtest()
         try:
             rgpd = result.find_element(By.ID, "onetrust-accept-btn-handler")
+
+
             rgpd.click()
             return result
         except NoSuchElementException:
@@ -218,6 +220,8 @@ class Yspeed:
         """
         system = platform.system().lower()
 
+
+
         if system == "windows":
             browser_executables = {
                 "chrome": "chrome.exe",
@@ -342,6 +346,7 @@ def gather_network_info(speedtest: Yspeed, progress: Progress) -> dict:
         }
 
 
+
 def print_network_info(console: Console, info: dict) -> None:
     """
     This function (print_network_info) prints the network information
@@ -405,7 +410,9 @@ def print_network_info(console: Console, info: dict) -> None:
 
 
 def _version() -> str:
-    return "0.1.3"
+    return "0.1.5"
+
+
 
 
 def author() -> None:
@@ -420,6 +427,8 @@ def author() -> None:
     console.print(f"Version Yspeed: {_version()}", style="grey35", justify="center")
 
 
+
+
 def clear_screen() -> None:
     """
     Clears the terminal screen based on the operating system.
@@ -427,6 +436,7 @@ def clear_screen() -> None:
     system_name = platform.system()
     if system_name == "Windows":
         # do something specific for Windows
+
         os.system("cls")
     elif system_name == "Linux":
         # do something specific for Linux
@@ -465,5 +475,6 @@ def main() -> None:
         sys.exit(0)
 
 
+
 if __name__ == "__main__":
     main()
